==> huaweicloudsdkkms-3.0.45-py2.py3-none-any.whl: huaweicloudsdkkms/v1/model/stage.py <==
# coding: utf-8

import pprint
import re

import six





class Stage:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'update_time': 'int',
        'secret_id': 'str',
        'version_id': 'str'
    }

    attribute_map = {
        'name': 'name',
        'update_time': 'update_time',
        'secret_id': 'secret_id',
        'version_id': 'version_id'
    }

    def __init__(self, name=None, update_time=None, secret_id=None, version_id=None):
        """Stage - a model defined in huaweicloud sdk"""
        
        

        self._name = None
        self._update_time = None
        self._secret_id = None
        self._version_id = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if update_time is not None:
            self.update_time = update_time
        if secret_id is not None:
            self.secret_id = secret_id
        if version_id is not None:
            self.version_id = version_id

    @property
    def name(self):
        """Gets the name of this Stage.

        凭据的版本状态名称。  约束：最小长度1，最大长度64。 

        :return: The name of this Stage.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Stage.

        凭据的版本状态名称。  约束：最小长度1，最大长度64。 

        :param name: The name of this Stage.
        :type: str
        """
        self._name = name

    @property
    def update_time(self):
        """Gets the update_time of this Stage.

        凭据的版本状态更新的时间戳，时间戳，即从1970年1月1日至该时间的总秒数。

        :return: The update_time of this Stage.
        :rtype: int
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this Stage.

        凭据的版本状态更新的时间戳，时间戳，即从1970年1月1日至该时间的总秒数。

        :param update_time: The update_time of this Stage.
        :type: int
        """
        self._update_time = update_time

    @property
    def secret_id(self):
        """Gets the secret_id of this Stage.

        凭据的资源标识符。

        :return: The secret_id of this Stage.
        :rtype: str
        """
        return self._secret_id

    @secret_id.setter
    def secret_id(self, secret_id):
        """Sets the secret_id of this Stage.

        凭据的资源标识符。

        :param secret_id: The secret_id of this Stage.
        :type: str
        """
        self._secret_id = secret_id

    @property
    def version_id(self):
        """Gets the version_id of this Stage.

        凭据的版本号标识符。 

        :return: The version_id of this Stage.
        :rtype: str
        """
        return self._version_id

    @version_id.setter
    def version_id(self, version_id):
        """Sets the version_id of this Stage.

        凭据的版本号标识符。 

        :param version_id: The version_id of this Stage.
        :type: str
        """
        self._version_id = version_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Stage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkkms-3.0.52-py2.py3-none-any.whl: huaweicloudsdkkms/v1/model/stage.py <==
# coding: utf-8

import re
import six





class Stage:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'update_time': 'int',
        'secret_id': 'str',
        'version_id': 'str'
    }

    attribute_map = {
        'name': 'name',
        'update_time': 'update_time',
        'secret_id': 'secret_id',
        'version_id': 'version_id'
    }

    def __init__(self, name=None, update_time=None, secret_id=None, version_id=None):
        """Stage - a model defined in huaweicloud sdk"""
        
        

        self._name = None
        self._update_time = None
        self._secret_id = None
        self._version_id = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if update_time is not None:
            self.update_time = update_time
        if secret_id is not None:
            self.secret_id = secret_id
        if version_id is not None:
            self.version_id = version_id

    @property
    def name(self):
        """Gets the name of this Stage.

        凭据的版本状态名称。  约束：最小长度1，最大长度64。 

        :return: The name of this Stage.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Stage.

        凭据的版本状态名称。  约束：最小长度1，最大长度64。 

        :param name: The name of this Stage.
        :type: str
        """
        self._name = name

    @property
    def update_time(self):
        """Gets the update_time of this Stage.

        凭据的版本状态更新的时间戳，时间戳，即从1970年1月1日至该时间的总秒数。

        :return: The update_time of this Stage.
        :rtype: int
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this Stage.

        凭据的版本状态更新的时间戳，时间戳，即从1970年1月1日至该时间的总秒数。

        :param update_time: The update_time of this Stage.
        :type: int
        """
        self._update_time = update_time

    @property
    def secret_id(self):
        """Gets the secret_id of this Stage.

        凭据的资源标识符。

        :return: The secret_id of this Stage.
        :rtype: str
        """
        return self._secret_id

    @secret_id.setter
    def secret_id(self, secret_id):
        """Sets the secret_id of this Stage.

        凭据的资源标识符。

        :param secret_id: The secret_id of this Stage.
        :type: str
        """
        self._secret_id = secret_id

    @property
    def version_id(self):
        """Gets the version_id of this Stage.

        凭据的版本号标识符。 

        :return: The version_id of this Stage.
        :rtype: str
        """
        return self._version_id

    @version_id.setter
    def version_id(self, version_id):
        """Sets the version_id of this Stage.

        凭据的版本号标识符。 

        :param version_id: The version_id of this Stage.
        :type: str
        """
        self._version_id = version_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Stage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
